@@ -395,120 +395,16 @@ class MultipleChoiceDataType( StringDataType ):
                 raise UserValueError( parameter = param , msg = msg )
         return True
 
-
-class AbstractTextDataType( DataType ):
+class AbstractFileDataType(DataType):
+    """
+    AbstractFileDataType is an abstract class that centralizes the
+    code which is common to text files (AbstractTextDataType) and
+    binary files (BinaryDataType)
+    """
 
     def isFile( self ):
-        return True  
-    
-    def head( self , data ):
-        return data[ 0 : 50 ]
-    
-    def cleanData( self , data ):
-        """
-        convert the data in right encoding and replace windows end of line by unix one.
-        """
-        # trying to guess the encoding, before converting the data to ascii
-        try:
-            # trying ascii
-            data = unicode(data.decode('ascii','strict'))
-        except:
-            try:
-                # utf8 codec with BOM support
-                data = unicode(data,'utf_8_sig')
-            except:
-                try:
-                    # utf16 (default Windows Unicode encoding)
-                    data = unicode(data,'utf_16')
-                except:
-                    # latin1
-                    data = unicode(data,'latin1')
-        # converting the unicode data to ascii
-        data = data.encode('ascii','replace')
-        return  re.sub( "\r\n|\r|\n" , '\n' , data )
+        return True
 
-
-    def toFile( self , data  , dest , destFileName , src , srcFileName ):
-        """
-        Write file (of user data) in dest directory .
-        @param fileName:
-        @type fileName: string
-        @param data: the content of the file
-        @type data: string
-        @param dest: the object in which the data will be copied
-        @type dest: Job, Session object
-        @param src: the object where the data can be found
-        @type src: Job, Session object
-        @param srcFileName: the file namae of the data in the src ( basename )
-        @type srcFileName: string
-        @return: the name of the created file (the basename)
-        @rtype: string
-        @raise: L{UserValueError} when filename is not allowed (for security reason)
-        @raise: L{MobyleError} if an error occured during the file creation
-        """
-        try:
-            destSafeFileName = safeFileName( destFileName )            
-        except UserValueError, err:
-            raise UserValueError( msg = "this value : %s is not allowed for a file name, please change it" % destFileName )
-        abs_DestFileName= os.path.join( dest.getDir() , destSafeFileName )
-        # if the user upload 2 files with the same basename safeFileName
-        # return the same safeFileName
-        # add an extension to avoid _toFile erase the existing file.
-        ext = 1
-        completeName = abs_DestFileName.split( '.' )
-        base = completeName[0]
-        suffixe = '.'.join( completeName[1:] )
-        while os.path.exists( abs_DestFileName ):
-            abs_DestFileName = base + '.' + str( ext ) + '.' + suffixe
-            ext = ext + 1
-        if src:
-            if src.isLocal():
-                try:
-                    srcSafeFileName = safeFileName( srcFileName )
-                except UserValueError, err:
-                    raise UserValueError( msg = "this value : %s is not allowed for a file name, please change it" % srcFileName )
-                #the realpath is because if the abs_SrcFileName is a soft link ( some results are ) the
-                # hardlink point to softlink and it causse ane error : no such file 
-                abs_SrcFileName = os.path.realpath( os.path.join( src.getDir() , srcSafeFileName ) )
-                try:
-                    os.link(  abs_SrcFileName , abs_DestFileName )
-                except OSError :
-                    #if the src and dest are not on the same device
-                    #an OSError: [Errno 18] Invalid cross-device link , is raised
-                    try:
-                        shutil.copy( abs_SrcFileName , abs_DestFileName )
-                    except IOError ,err:
-                        # I don't know  - neither the service ( if it exists )
-                        #               - nor the job or session ID 
-                        # I keep the Job or the Session to log this error 
-                        msg = "can't copy data from %s to %s : %s" %( abs_SrcFileName ,
-                                                                      abs_DestFileName ,
-                                                                      err )
-                        c_log.error( msg )
-                        raise MobyleError , "can't copy data : "+ str(err)
-            else: #src is a job , jobState , MobyleJob instance ( Session is always Local )
-                data = src.getOutputFile( srcFileName )
-                try:
-                    f = open( abs_DestFileName , 'w' )
-                    f.write( data )
-                    f.close()
-                except IOError ,err:
-                    msg = "unable to write data from %s to %s: %s"%(src , dest , err )
-                    c_log.error( msg )
-                    raise MobyleError , msg
-        else:
-            clean_content = self.cleanData( data )
-            try:
-                fh = open( abs_DestFileName , "w" )
-                fh.write( clean_content )
-                fh.close()
-            except IOError , err:
-                msg = "error when creating file : " + abs_DestFileName + str( err )
-                raise MobyleError , msg
-        size = os.path.getsize( abs_DestFileName )
-        return os.path.basename( abs_DestFileName ) , size
-    
-    
     @classmethod
     def supportedFormat( cls ):
         """
@@ -534,8 +430,7 @@ class AbstractTextDataType( DataType ):
                 if f not in uniq_conversion:
                     uniq_conversion.append( f )
         return uniq_conversion
-    
-    
+
     def detect( self , value  ):
         """
         detects the format of the sequence(s) contained in fileName
@@ -701,8 +596,121 @@ class AbstractTextDataType( DataType ):
                 return True
             else:
                 return os.path.exists( param.getValue() )
-        
 
+    
+class AbstractTextDataType( AbstractFileDataType ):
+
+    def head( self , data ):
+        return data[ 0 : 50 ]
+    
+    def cleanData( self , data ):
+        """
+        convert the data in right encoding and replace windows end of line by unix one.
+        """
+        # trying to guess the encoding, before converting the data to ascii
+        try:
+            # trying ascii
+            data = unicode(data.decode('ascii','strict'))
+        except:
+            try:
+                # utf8 codec with BOM support
+                data = unicode(data,'utf_8_sig')
+            except:
+                try:
+                    # utf16 (default Windows Unicode encoding)
+                    data = unicode(data,'utf_16')
+                except:
+                    # latin1
+                    data = unicode(data,'latin1')
+        # converting the unicode data to ascii
+        data = data.encode('ascii','replace')
+        return  re.sub( "\r\n|\r|\n" , '\n' , data )
+
+
+    def toFile( self , data  , dest , destFileName , src , srcFileName ):
+        """
+        Write file (of user data) in dest directory .
+        @param fileName:
+        @type fileName: string
+        @param data: the content of the file
+        @type data: string
+        @param dest: the object in which the data will be copied
+        @type dest: Job, Session object
+        @param src: the object where the data can be found
+        @type src: Job, Session object
+        @param srcFileName: the file namae of the data in the src ( basename )
+        @type srcFileName: string
+        @return: the name of the created file (the basename)
+        @rtype: string
+        @raise: L{UserValueError} when filename is not allowed (for security reason)
+        @raise: L{MobyleError} if an error occured during the file creation
+        """
+        try:
+            destSafeFileName = safeFileName( destFileName )            
+        except UserValueError, err:
+            raise UserValueError( msg = "this value : %s is not allowed for a file name, please change it" % destFileName )
+        abs_DestFileName= os.path.join( dest.getDir() , destSafeFileName )
+        # if the user upload 2 files with the same basename safeFileName
+        # return the same safeFileName
+        # add an extension to avoid _toFile erase the existing file.
+        ext = 1
+        completeName = abs_DestFileName.split( '.' )
+        base = completeName[0]
+        suffixe = '.'.join( completeName[1:] )
+        while os.path.exists( abs_DestFileName ):
+            abs_DestFileName = base + '.' + str( ext ) + '.' + suffixe
+            ext = ext + 1
+        if src:
+            if src.isLocal():
+                try:
+                    srcSafeFileName = safeFileName( srcFileName )
+                except UserValueError, err:
+                    raise UserValueError( msg = "this value : %s is not allowed for a file name, please change it" % srcFileName )
+                #the realpath is because if the abs_SrcFileName is a soft link ( some results are ) the
+                # hardlink point to softlink and it causse ane error : no such file 
+                abs_SrcFileName = os.path.realpath( os.path.join( src.getDir() , srcSafeFileName ) )
+                try:
+                    os.link(  abs_SrcFileName , abs_DestFileName )
+                except OSError :
+                    #if the src and dest are not on the same device
+                    #an OSError: [Errno 18] Invalid cross-device link , is raised
+                    try:
+                        shutil.copy( abs_SrcFileName , abs_DestFileName )
+                    except IOError ,err:
+                        # I don't know  - neither the service ( if it exists )
+                        #               - nor the job or session ID 
+                        # I keep the Job or the Session to log this error 
+                        msg = "can't copy data from %s to %s : %s" %( abs_SrcFileName ,
+                                                                      abs_DestFileName ,
+                                                                      err )
+                        c_log.error( msg )
+                        raise MobyleError , "can't copy data : "+ str(err)
+            else: #src is a job , jobState , MobyleJob instance ( Session is always Local )
+                data = src.getOutputFile( srcFileName )
+                try:
+                    f = open( abs_DestFileName , 'w' )
+                    f.write( data )
+                    f.close()
+                except IOError ,err:
+                    msg = "unable to write data from %s to %s: %s"%(src , dest , err )
+                    c_log.error( msg )
+                    raise MobyleError , msg
+        else:
+            try:
+                clean_content = self.cleanData( data )
+            except Exception, err :
+                msg = "error when cleaning file : " + abs_DestFileName + str( err )
+                c_log.critical( msg , exc_info= True )
+                raise MobyleError , msg
+            try:
+                fh = open( abs_DestFileName , "w" )
+                fh.write( clean_content )
+                fh.close()
+            except IOError , err:
+                msg = "error when creating file : " + abs_DestFileName + str( err )
+                raise MobyleError , msg
+        size = os.path.getsize( abs_DestFileName )
+        return os.path.basename( abs_DestFileName ) , size
 
 class TextDataType( AbstractTextDataType ):
     # this trick is to avoid that SequenceDataType is a subclass of TextDataType
@@ -713,11 +721,8 @@ class ReportDataType( AbstractTextDataType ):
     pass
 
 
-class BinaryDataType( DataType ):
+class BinaryDataType( AbstractFileDataType ):
 
-    def isFile( self ):
-        return True
-    
     def head( self , data ):
         return 'Binary data'
             
@@ -729,7 +734,6 @@ class BinaryDataType( DataType ):
         """
         return data
 
-
     def toFile( self , data , dest , destFileName , src , srcFileName ):
         """
         Write file (of user data) in the working directory .
@@ -805,60 +809,6 @@ class BinaryDataType( DataType ):
         size  = os.path.getsize( abs_DestFileName )
         return os.path.basename( abs_DestFileName ) , size
     
-    def detect( self , value ):
-        mt = MobyleType( self )
-        return mt
-    
-    def convert( self , value , acceptedMobyleType , detectedMobyleType = None , paramFile= False ):
-        """
-        Do the generals control and cast the value in the right type.
-        if a control or the casting fail a MobyleError is raised
-
-        @param value: the value provided by the User for this parameter
-        @type value: String
-        @param acceptedMobyleType: the MobyleType  accepted by this service parameter 
-        @type acceptedMobyleType: L{MobyleType} instance
-        @param detectedMobyleType: the MobyleType discribing this data
-        @type detectedMobyleType: L{MobyleType} instance
-        @return: the fileName ( basename ) of the binary file
-        """
-        if value is None:
-            return None
-        elif len( value ) == 5 :
-            data , dest , destFileName , src , srcFileName = value
-        else:
-            raise MobyleError ,"value must be a tuple of 5 elements: ( data , dest , destFileName , src , srcFileName )"
-        if destFileName is None:
-            return None
-        if dest is None:
-            raise MobyleError, "the destination is mandatory"
-        if  data and src :
-            raise MobyleError, "you cannot specify data and src at the same time"
-        if not data and ( not dest or not src ) :
-            raise MobyleError , "if data is not specified, dest and src must be defined"
-        if src and not srcFileName :
-            raise MobyleError , "if src is specified, srcFileName must be also specified"
-        #safeFileName return a basename
-        fileName = safeFileName( destFileName )
-        mt = MobyleType( self )
-        return ( fileName , mt )
-
-
-    def validate( self, param ):
-        """
-        @todo: il faudrait avoir value = None et verifier file names
-        """
-        if param.isout():
-            value = param.getValue()
-            if value is None :
-                return True
-            else:
-                return False
-        else:        
-            return os.path.exists( param.getValue() )
-        
-
-
 class FilenameDataType( DataType ):
  
     def convert( self , value , acceptedMobyleType , detectedMobyleType = None , paramFile= False ):  
