@@ -2,7 +2,7 @@
 #                                                                                      #
 #   Author: Bertrand Neron,                                                            #
 #   Organization:'Biological Software and Databases' Group, Institut Pasteur, Paris.   #  
-#   Distributed under LGPLv2 Licence. Please refer to the COPYING.LIB document.        #
+#   Distributed under GPLv2 Licence. Please refer to the COPYING.LIB document.        #
 #                                                                                      #
 ########################################################################################
 
@@ -58,7 +58,7 @@ class Config( object ):
     __metaclass__ = MetaSingleton
     
     def __init__(self):
-            self.__version = '1.0.3'
+            self.__version = '1.0.6'
             import Local.Config.Config
             import Local.Config.Execution
             #############################
@@ -651,6 +651,12 @@ class Config( object ):
                 self._portal_name = Local.Config.Config.PORTAL_NAME
             except AttributeError:
                 pass
+            
+            self._simple_forms_active = False
+            try:
+                self._simple_forms_active = Local.Config.Config.SIMPLE_FORMS
+            except AttributeError:
+                pass
 
             try:
                 self._all_portals = Local.Config.Config.PORTALS 
@@ -1226,7 +1232,13 @@ class Config( object ):
         @rtype: String
         """
         return self._portal_name
-    
+
+    def simple_forms_active( self ):
+        """
+        @return: tells if "simple forms" should be displayed by default
+        @rtype: Boolean
+        """
+        return self._simple_forms_active
     
     def portals( self ):
         """
