@@ -24,14 +24,16 @@ acc_log = getLogger('Mobyle.access')
 from Mobyle.MobyleJob  import MobyleJob
 from  Mobyle.Parser import parseService
 from Mobyle.JobState import JobState
-from Mobyle.MobyleError import MobyleError, UserValueError
+from Mobyle.MobyleError import MobyleError, UserValueError, NoSpaceLeftError
 from Mobyle.Registry import registry
 from Mobyle.WorkflowJob import WorkflowJob
 from Mobyle.Workflow import Workflow, Parser
 from Mobyle.Service import Program
 from Mobyle.Utils import getStatus as utils_getStatus , killJob as utils_killJob
 from Mobyle.Status import Status
+from Mobyle.StatusManager import StatusManager
 from Mobyle.DataProvider import DataProvider
+from JobState import ProgramJobState, WorkflowJobState
 
 from Mobyle.ConfigManager import Config
 _cfg = Config()
@@ -65,19 +67,22 @@ class JobFacade(object):
         @type: dictionary
         """
         dataUsed = []
-        for param in [param for param in self.params.values() \
+        for name, param in [(name, param) for name, param in self.params.items() \
                       if (param.has_key('parameter') \
                       and param['parameter'].isInfile())]:
-            if param['srcFileName'] and not(param['value']):
-                param['userName'] = session.getData(param['srcFileName'])['userName']
-                dataUsed.append(param['srcFileName'])
-            if param['value'] and not(param['srcFileName']):
-                param['srcFileName'] = \
-                session.addData( param['userName'], \
-                                  param['parameter'].getType(), \
-                                  content = param['value'], \
-                                  inputModes = [param['inputMode']])
-                dataUsed.append(param['srcFileName'])
+                if param['srcFileName'] and not(param['value']):
+                    param['userName'] = session.getData(param['srcFileName'])['userName']
+                    dataUsed.append(param['srcFileName'])
+                if param['value'] and not(param['srcFileName']):
+                    try:
+                        param['srcFileName'] = \
+                        session.addData( param['userName'], \
+                                          param['parameter'].getType(), \
+                                          content = param['value'], \
+                                          inputModes = [param['inputMode']])
+                    except NoSpaceLeftError, err:
+                        raise UserValueError(param, msg=err.message)
+                        dataUsed.append(param['srcFileName'])
         session.addJob( jobInfo['id'],dataUsed=dataUsed)
 
     def _processForm(self):
@@ -130,7 +135,7 @@ class JobFacade(object):
             self.service.url = self.workflowUrl
             self.servicePID = registry.workflowsByUrl[ self.workflowUrl ].pid   
   
-    def create(self, request_fs=None, request_dict=None, session=None):
+    def create(self, request_fs=None, request_dict=None, session=None,simulate=False):
         """
         create sets up most of the class attributes TODO: check if this could be done in __init__?
         """
@@ -140,18 +145,30 @@ class JobFacade(object):
         elif request_fs:
             for key in request_fs.keys():
                 self.request[key] = request_fs.getvalue(key)
+        serviceDef = None
+        if self.request.get('programName',None):
+            serviceDef = registry.programsByUrl[self.request.get('programName')]
+        elif self.request.get('workflowUrl',None):
+            serviceDef = registry.workflowsByUrl[ self.request.get( 'workflowUrl')]
+        simulate = simulate or self.request.get('mobyle:simulate', False)=='true'
+        if not(simulate) and not(session) and (serviceDef.server.name=='local' and not(serviceDef.isExported()))\
+            and not(self.workflowId and registry.isJobLocal(self.workflowId)):
+            # test if service is exported is needed unless it is only a simulation
+            raise MobyleError("unauthorized access to service %s@%s, which is restricted to local use." % (serviceDef.name,serviceDef.server.name))
         self.email = self.request.get('email', None)
         if not(self.email) and session:
             self.email = session.getEmail()
         self.parseService()
-        if ( not( self.email ) and not( _cfg.opt_email( self.servicePID ) ) ):
+        if (not(simulate) and not( self.email ) and not( _cfg.opt_email( self.servicePID ) ) ):
+            # test if email is needed unless it is only a simulation
             return {"emailNeeded":"true"}
-        if (session and not(session.isActivated())):
+        if (not(simulate) and session and not(session.isActivated())):
+            # test if session is active is needed unless it is only a simulation
             return {"activationNeeded":"true"}                
         self.params = {}
         self.session = session
         self._processForm()
-        resp = self.submit(session)
+        resp = self.submit(session,simulate)
         if resp.has_key('id'):
             self.jobId = resp['id']
             resp['pid'] = str(registry.getJobPID(resp['id']))
@@ -197,15 +214,21 @@ class JobFacade(object):
         """
         j=None
         if programUrl:
-            if registry.programsByUrl[programUrl].server.name=='local':
-                j = LocalJobFacade(programUrl=programUrl, workflowId=workflowId)
+            if registry.programsByUrl.has_key(programUrl):
+                if registry.programsByUrl[programUrl].server.name=='local':
+                    j = LocalJobFacade(programUrl=programUrl, workflowId=workflowId)
+                else:
+                    j = RemoteJobFacade(programUrl=programUrl, workflowId=workflowId)
             else:
-                j = RemoteJobFacade(programUrl=programUrl, workflowId=workflowId)
+                raise MobyleError(msg="Service for url %s cannot be found" % programUrl)
         elif workflowUrl:
-            if registry.workflowsByUrl[workflowUrl].server.name=='local':
-                j = LocalJobFacade(workflowUrl=workflowUrl, workflowId=workflowId)
+            if registry.workflowsByUrl.has_key(workflowUrl):
+                if registry.workflowsByUrl[workflowUrl].server.name=='local':
+                    j = LocalJobFacade(workflowUrl=workflowUrl, workflowId=workflowId)
+                else:
+                    j = RemoteJobFacade(workflowUrl=workflowUrl, workflowId=workflowId)
             else:
-                j = RemoteJobFacade(workflowUrl=workflowUrl, workflowId=workflowId)
+                raise MobyleError(msg="Service for url %s cannot be found" % workflowUrl)
         elif service is not None:
             j = LocalJobFacade(service=service, workflowId=workflowId)
         return j
@@ -247,7 +270,7 @@ class RemoteJobFacade(JobFacade):
             self.server = registry.workflowsByUrl[self.workflowUrl].server
         self.endpoint = self.server.url
 
-    def submit(self, session=None):
+    def submit(self, session=None, simulate=False):
         """
         submits the job on the remote server
         @param session: the session used to load infile values
@@ -274,6 +297,8 @@ class RemoteJobFacade(JobFacade):
             requestDict['workflowUrl'] = self.workflowUrl            
         if self.email:
             requestDict['email'] = self.email
+        if simulate:
+            requestDict['mobyle:simulate'] = 'true'
         requestDict['workflowId'] = self.workflowId            
         for name, param in self.params.items():
             requestDict[name] = param['value']
@@ -385,7 +410,7 @@ class LocalJobFacade(JobFacade):
     """
 
 
-    def submit(self, session=None):
+    def submit(self, session=None, simulate=False):
         """
         submits the job on the local server
         @param session: the session used to load infile values
@@ -398,28 +423,40 @@ class LocalJobFacade(JobFacade):
                 self.job = MobyleJob( service    = self.service , 
                                       email      = self.email,
                                       session    = session,
-                                      workflowID = self.workflowId)
+                                      workflowID = self.workflowId,
+                                      debug = (None,1)[simulate])
             elif isinstance(self.service, Workflow):
                 self.job = WorkflowJob( workflow   = self.service,
                                         email      = self.email,
                                         session    = session,
                                         workflowID = self.workflowId)
+                                        #debug = (None,1)[simulate])
             else:
                 raise NotImplementedError("No Job can be instanciated for a %s service" % str(self.service.__class__))
             for name, param in self.params.items():
-                if param['parameter'].isInfile():
-                    if param['src']:
-                        param['src'] = DataProvider.get(param['src'])
-                        self.job.setValue(name, (param['userName'], None, param['src'], param['srcFileName']))      
+                try:
+                    if param['parameter'].isInfile():
+                        if param['src']:
+                            param['src'] = DataProvider.get(param['src'])
+                            self.job.setValue(name, (param['userName'], None, param['src'], param['srcFileName']))      
+                        else:
+                            self.job.setValue(name, (param['userName'], param['value'], None, None))      
                     else:
-                        self.job.setValue(name, (param['userName'], param['value'], None, None))      
-                else:
-                    if param['parameter'].getDataType().getName() == 'MultipleChoice': 
-                        from types import StringTypes
-                        if isinstance(  param['value'] , StringTypes ):
-                            param['value'] = [ param['value'] ]
-                    self.job.setValue(name, param['value'])
-            # run Job
+                        if param['parameter'].getDataType().getName() == 'MultipleChoice': 
+                            from types import StringTypes
+                            if isinstance(  param['value'] , StringTypes ):
+                                param['value'] = [ param['value'] ]
+                        self.job.setValue(name, param['value'])
+                except MobyleError , err:
+                    if param['parameter'].promptHas_lang( "en"):
+                        userMsg = "Error while setting value for parameter: %s " %param['parameter'].getPrompt( lang="en")
+                    else:
+                        userMsg = "Error while setting value for parameter: %s " %name
+                    sm = StatusManager ()
+                    sm.setStatus( self.job.getDir() , Status( code = 5 , message = userMsg ) )
+                    j_log.error(userMsg,exc_info=True)
+                    raise err
+            # run Job         
             self.job.run()
             return {
                     'id': str(self.job.getJobid()),
@@ -427,6 +464,7 @@ class LocalJobFacade(JobFacade):
                     'status': str( self.job.getStatus() ),
                     }
         except UserValueError, e:
+            jobId = None
             if hasattr(e, 'message') and e.message:
                 msg = {'errormsg':str(e.message)}
             else:
@@ -487,6 +525,20 @@ class LocalJobFacade(JobFacade):
             return subjobs
         else:
             return []
+    
+    def getExecutionDetails(self):
+        js = JobState(self.jobId)
+        execution_details = {}
+        if isinstance(js.state,ProgramJobState):
+            execution_details['cmd']=js.getCommandLine()
+            # TODO it should be specified if the contents
+            # of the paramfiles have to be sent back as well
+            execution_details['paramfiles']=js.getParamfiles()
+            # TODO the environment vars are not stored except in the .forChild.dump
+            # we can do something about it if necessary, otherwise accessing them
+            # is too much work...
+            #execution_details['env']=self.job._job.runner._xmlEnv
+        return execution_details
 
         
     def killJob(self):
