@@ -997,7 +997,7 @@ class ProgramJobState( _abstractState ):
 
     def getParamfiles(self):
         """
-        @return: a list containing the results filename. if there isn't any result return None
+        @return: a list containing the parameter files description. if there isn't any result return None
         @rtype: list of tuple ( string filename , long size )
         """
         self._parse( )
