@@ -32,7 +32,7 @@ _extra_epydoc_fields__ = [('call', 'Called by','Called by')]
 class MobyleJob:
     """this class is the interface with the cgis to submit a job"""
     
-    def __init__(self, progUrl= None , email = None , service = None, params = None, evaluator = None , ID = None , session = None , cfg = None , workflowID = None , email_notify= 'auto'):
+    def __init__(self, progUrl= None , email = None , service = None, params = None, evaluator = None , ID = None , session = None , cfg = None , workflowID = None , email_notify= 'auto', debug=None):
         """
         We could instanciate a MobyleJob whith a progName or directly with a Service instance , with params or a Evaluation instance.
         if we instanciate a MobyleJob with a progName mobyleJob will instanciate a service corresponding to this name .
@@ -106,6 +106,9 @@ class MobyleJob:
                 email = session.getEmail()
                 if email:
                     self.userEmail = EmailAddress( session.getEmail() )
+                    resp = self.userEmail.checkBlackList()
+                    if not resp.status:
+                        raise UserValueError( msg = resp.user_message )
                 else:
                     self.userEmail = None
             elif email :
@@ -113,33 +116,29 @@ class MobyleJob:
                     self.userEmail = EmailAddress( email )
                 else:
                     self.userEmail = email
-                chk = self.userEmail.check()
-                if not chk:
-                    msg = self.userEmail.getMessage()
-                    userMsg = "you are not allowed to run on this server for now "
-                    
+                resp = self.userEmail.check()
+                if not resp.status:
                     msg = "%s %s %s %s" %( jobName ,
                                            unicode( str( self.userEmail ).decode('ascii', 'replace')).encode( 'ascii', 'replace' ) ,
                                            remoteLog ,
-                                           "FORBIDDEN "+ msg
+                                           "FORBIDDEN "+ resp.message
                                            )
                     self.m_log.info( msg )
-                    raise UserValueError( msg = userMsg )                 
+                    raise UserValueError( msg = resp.user_message )                 
             else:
                 self.userEmail = None
             email_notify = email_notify.lower()
-            try:
-                checkHost()
-            except UserValueError ,err:
+            resp =  checkHost()
+            if not resp.status:
                 msg = "%s %s %s %s %s" %( jobName,
                                           unicode( str( email ).decode('ascii', 'replace')).encode( 'ascii', 'replace' ) ,
                                           remoteLog ,
                                           "FORBIDDEN ",
-                                           err
+                                           resp.message
                                           )
                 
-                self.m_log.info( msg )
-                raise UserValueError( msg = "you are not allowed to run a job on this server for now " )
+                self.m_log.warning( msg )
+                raise UserValueError( msg = resp.user_message )
 
             ## building the MobyleJob
             self.progUrl = progUrl
@@ -182,13 +181,14 @@ class MobyleJob:
                         self._evaluator = self._service.getEvaluator()
                     else:
                         self._service.setEvaluator( evaluator )
-                self._debug = self.cfg.debug( self._service.getName() )
+                self._debug = debug or self.cfg.debug( self._service.getName() )
                 self._job = Job( self._service ,
                                             self.cfg ,
                                             userEmail = self.userEmail ,
                                             session = self.session ,
                                             workflowID = workflowID ,
-                                            email_notify = email_notify
+                                            email_notify = email_notify,
+                                            debug=debug
                                             )
             else: #params is not None
                 if service is None:
@@ -387,11 +387,9 @@ class MobyleJob:
                             self.build_log.debug( "self._service.setValue( %s , %s )" %( paramName , converted_value ) )
                         except:
                             self.build_log.debug( "!!!!!!!! problem during reporting log !!!!!!!!!!!!" )
-                except UserValueError , err:
+                except UserValueError, err:
                         msg =  str( err )
-                        self._logError( logMsg = msg ,
-                                        userMsg = msg
-                                        )
+                        self._logError( logMsg = msg ,userMsg = msg)
                         raise UserValueError(parameter=parameter, msg=msg)
                     
                 newValue = parameter.getValue( )
@@ -1007,7 +1005,6 @@ class MobyleJob:
 
         
     def _logError( self , userMsg = None , logMsg = None ):
-       
         
         if userMsg:
             sm = StatusManager ()
