@@ -247,7 +247,7 @@ def parseParagraph( paragraphNode , evaluator  = None , dataTypeFactory = None ,
 def parseParameter( parameterNode , evaluator = None , dataTypeFactory = None , context = None):
     attrs = parameterNode.attrib
     try: 
-        out = attrs.get( 'isout' , None ) == "1" or  attrs.get( 'isstdout' , None ) == "1" 
+        out = attrs.get( 'isout' , None ) in ["1","true"] or  attrs.get( 'isstdout' , None ) in ["1","true"]
         typeNode = parameterNode.find( "./type")
         mobyleType = parseType(  typeNode , 
                                  dataTypeFactory = dataTypeFactory , 
@@ -267,19 +267,19 @@ def parseParameter( parameterNode , evaluator = None , dataTypeFactory = None ,
     #                           #
     #############################
     
-    if 'ismandatory' in attrs and  attrs[ 'ismandatory' ] == "1":
+    if 'ismandatory' in attrs and  attrs[ 'ismandatory' ] in ["1","true"]:
         parameter.setMandatory( True )
-    if 'ismaininput' in attrs and  attrs[ 'ismaininput' ] == "1":
+    if 'ismaininput' in attrs and  attrs[ 'ismaininput' ] in ["1","true"]:
         parameter.setMaininput( True )
-    if 'iscommand' in attrs and  attrs[ 'iscommand' ] == "1":
+    if 'iscommand' in attrs and  attrs[ 'iscommand' ] in ["1","true"]:
         parameter.setCommand( True )
-    if 'ishidden' in attrs and  attrs[ 'ishidden' ] == "1":
+    if 'ishidden' in attrs and  attrs[ 'ishidden' ] in ["1","true"]:
         parameter.setHidden( True )
-    if 'issimple' in attrs and  attrs[ 'issimple' ] == "1":  
+    if 'issimple' in attrs and  attrs[ 'issimple' ] in ["1","true"]:  
         parameter.setSimple( True )
-    if 'isout' in attrs and  attrs[ 'isout' ] == "1":
+    if 'isout' in attrs and  attrs[ 'isout' ] in ["1","true"]:
         parameter.setOut( True )
-    if 'isstdout' in attrs and  attrs[ 'isstdout' ] == "1": 
+    if 'isstdout' in attrs and  attrs[ 'isstdout' ] in ["1","true"]: 
         parameter.setStdout( True )
         parameter.setOut( True )
     if 'bioMoby' in attrs and  attrs[ 'bioMoby' ] == "1":    
