@@ -123,10 +123,8 @@ class Session( object ):
         if  isinstance( email , types.StringTypes ):
             from Mobyle.Net import EmailAddress
             email = EmailAddress( email )
-        chk = email.check()
-        if not chk:
-            msg = email.getMessage()
-            userMsg = "you are not allowed to run on this server for now "
+        resp = email.check()
+        if not resp.status:
             remoteLog = "UNKNOWN"
             try:
                 remoteLog = os.environ[ 'REMOTE_ADDR' ]
@@ -140,11 +138,11 @@ class Session( object ):
             msg = "session/%s %s %s FORBIDDEN %s" % ( self.getKey() ,
                                                       unicode( str( email ).decode('ascii', 'replace')).encode( 'ascii', 'replace' ) ,
                                                       remoteLog ,
-                                                      msg
+                                                      resp.message
                                                     )
     
-            self.log.info( msg )
-            raise UserValueError( msg = userMsg )
+            self.log.warning( msg )
+            raise UserValueError( msg = resp.user_message )
             
         transaction = self._getTransaction( Transaction.WRITE )
         transaction.setEmail( email )
@@ -158,7 +156,7 @@ class Session( object ):
 
     def _cleanData( self , content , dataType ):
         """
-        clean the data send by the user, the cleanning depends of the parameter ( CRLF for Text etc...)
+        clean the data send by the user, the cleaning depends of the parameter ( CRLF for Text etc...)
         and calculate it's md5. the md5 is based on the data content and the datatype
         @return: the data after cleaning , and the md5 
         @rtype: ( string md5 , string data content )
@@ -250,7 +248,7 @@ class Session( object ):
        
         # to avoid md5 differences depending on the web client or platform
         # I clean the content prior to perform the md5
-        # be careful the cleanning must be adapted to the parameter
+        # be careful the cleaning must be adapted to the parameter
         # it's not the same between text and binary parameter
         dataType = mobyleType.getDataType()
         if producer and isinstance( producer , Session ):
@@ -341,6 +339,8 @@ class Session( object ):
                 transaction.linkJobInput2Data( [ dataID ] , usedBy )
             if producedBy:
                 transaction.linkJobOutput2Data( [ dataID ] , producedBy )
+            if inputModes:
+                transaction.addInputModes(dataID,inputModes)
             transaction.commit()
             return dataID 
      
@@ -371,10 +371,10 @@ class Session( object ):
         # set id
         ids = [value['id'] for value in transaction.getWorkflows()]
         if ids:
-            id = max(ids)+1
+            ID = max(ids)+1
         else:
-            id = 1
-        workflow.id = id
+            ID = 1
+        workflow.id = ID
         self.saveWorkflow(workflow)
         transaction.addWorkflowLink(workflow.id)
         transaction.commit()
@@ -402,24 +402,24 @@ class Session( object ):
         wffile.write( etree.tostring(workflow, xml_declaration=True , encoding='UTF-8', pretty_print= True )) 
         wffile.close()
 
-    def readWorkflow(self, id):
+    def readWorkflow(self, ID):
         """
         read a workflow from the session
-        @param id: the id of the workflow to be read
-        @type id: string
+        @param ID: the id of the workflow to be read
+        @type ID: string
         """
         # save workflow
         from Mobyle.Workflow import parser, MobyleLookup
         parser.set_element_class_lookup(MobyleLookup())
-        return etree.parse(os.path.join(self.getDir(), 'workflow%s.xml' % str(id)), parser).getroot()
+        return etree.parse(os.path.join(self.getDir(), 'workflow%s.xml' % str(ID)), parser).getroot()
 
-    def getWorkflowUrl(self, id):
+    def getWorkflowUrl(self, ID):
         """
         return the url of a workflow
         @param id: the id of the workflow to be read
         @type id: string
         """
-        return self.url+'/workflow%s.xml' % id
+        return self.url+'/workflow%s.xml' % ID
 
     def _createNewData(self , safeUserName , content , dataID , producer , nameInProducer , mobyleType , dataBegining , usedBy = None , producedBy = None ,  inputModes = None ):
         """
@@ -435,7 +435,7 @@ class Session( object ):
         @type nameInProducer: string
         @param mobyleType: the MobyleType corresponding to this data
         @type mobyleType: L{MobyleType} instance
-        @param dataBegining: the begining (50 first chars )of the data
+        @param dataBegining: the beginning (50 first chars )of the data
         @type dataBegining: string
         @param usedBy: jobID(s) which used this data as input
         @type usedBy: string or sequence of strings
@@ -482,14 +482,14 @@ class Session( object ):
                                                                                                        dataID ,
                                                                                                        size
                                                                                                        ))
-            self.log.error( "session/%s : the data %s ( %d ) cannot be added because the session size exceed the session limit ( %d )" %(
+            self.log.error( "session/%s : the data %s ( %d ) cannot be added because the session size exceeds the storage limit ( %d )" %(
                                                                                                                                       self.getKey() ,           
                                                                                                                                       dataID ,
                                                                                                                                       size ,
                                                                                                                                       self.sessionLimit
                                                                                                                                       ) )
          
-            raise NoSpaceLeftError , "this data cannot be added to your bookmarks, because the resulting size exceed the limit ( %s )" % sizeFormat( self.sessionLimit )
+            raise NoSpaceLeftError , "this data cannot be added to your bookmarks, because the resulting size exceeds the storage limit ( %s )" % sizeFormat( self.sessionLimit )
         #dataID , userName , size , dataBegining , inputModes , format = None , producedBy = [] , usedBy = []    
         #must be clean only the format information must be uniq
         transaction = self._getTransaction( Transaction.WRITE )
@@ -802,15 +802,19 @@ class Session( object ):
         for job in jobs:
             jobExist = self.jobExists(job[ 'jobID' ])
             if jobExist == 1: #yes
-                job[ 'jobPID' ] = registry.getJobPID(job['jobID'])
-                results.append( job )
-                jf = JobFacade.getFromJobId( job[ 'jobID' ] )
-                job['subjobs']  = jf.getSubJobs() 
-                if job[ 'status' ].isQueryable():
-                    newStatus = jf.getStatus()
-                    if newStatus != job[ 'status' ]:
-                        job[ 'status' ] = newStatus
-                        job2updateStatus.append( ( job[ 'jobID' ] , newStatus ) )
+                try:
+                    job[ 'jobPID' ] = registry.getJobPID(job['jobID'])
+                    jf = JobFacade.getFromJobId( job[ 'jobID' ] )
+                    results.append( job )
+                    job['subjobs']  = jf.getSubJobs() 
+                    if job[ 'status' ].isQueryable():
+                        newStatus = jf.getStatus()
+                        if newStatus != job[ 'status' ]:
+                            job[ 'status' ] = newStatus
+                            job2updateStatus.append( ( job[ 'jobID' ] , newStatus ) )
+                except MobyleError, me:
+                    self.log.error( "problem accessing job %s: job is removed from session %s (%s)" %( job[ 'jobID' ] , self.getKey(), me.message ) )
+                    job2remove.append(job[ 'jobID' ])
             elif jobExist == 2 :# maybe
                 results.append(job)
             else: #the job does not exists anymore
