@@ -19,6 +19,7 @@ import os
 from subprocess import Popen, PIPE
 from Mobyle.ConfigManager import Config
 _cfg = Config()
+from tempfile import NamedTemporaryFile
 
 from logging import getLogger
 v_log = getLogger(__name__)
@@ -58,12 +59,20 @@ class Validator(object):
         self.runRNG_Jing = runRNG_Jing
         self.runSCH = runSCH
         
-        self.docPath = docPath
-                    
-        if docPath:        
-            self.doc = etree.parse(docPath, parser=net_enabled_parser)
+        self.file_is_temporary = False
+        if docPath:
+            self.docPath = docPath
         else:
-            self.doc = etree.fromstring(docString)
+            # if we pass an XML string, create a temporary file which
+            # will be parsed and passed to different validation steps
+            tmpXmlFile = NamedTemporaryFile(delete=False)
+            tmpXmlFile.write(docString)
+            tmpXmlFile.close()
+            self.docPath = tmpXmlFile.name
+            # this flag tells the object that the file path is 
+            # temporary and that it should be removed upon object destruction
+            self.file_is_temporary = True
+        self.doc = etree.parse(self.docPath, parser=net_enabled_parser)
         self.doc.xinclude()
         self.doc = rb_transform(self.doc)
 
@@ -72,22 +81,30 @@ class Validator(object):
             self.rngOk = self.mobrngVal.validate(self.doc)
             self.rngErrors = [self.mobrngVal.error_log.last_error]
         if self.runRNG_Jing:
-            cp = '-cp %s' % jingPath
-            val_cmd = ("java -Dorg.apache.xerces.xni.parser.XMLParserConfiguration=org.apache.xerces.parsers.XIncludeParserConfiguration %s com.thaiopensource.relaxng.util.Driver %s %s" % (cp, self.mobrngPath, self.docPath))
-            val_cmd = val_cmd.split(' ')
-            process = Popen(val_cmd , shell = False , stdout = PIPE, stderr = PIPE )
-            messages = []
-            for line in process.stdout:
-                if line.find('found attribute "xml:base", but no attributes allowed here')==-1:
-                    messages.append(line)
-            for line in process.stderr:
-                if line.find('found attribute "xml:base", but no attributes allowed here')==-1:
-                    messages.append(line)
-            process.wait()
-            #returnCode = process.poll()
-            #self.rng_JingOk = not(returnCode)
-            self.rng_JingOk = len(messages)==0
-            self.rng_JingErrors = messages
+            try:
+                cp = '-cp %s' % jingPath
+                val_cmd = ("java -Dorg.apache.xerces.xni.parser.XMLParserConfiguration=org.apache.xerces.parsers.XIncludeParserConfiguration %s com.thaiopensource.relaxng.util.Driver %s %s" % (cp, self.mobrngPath, self.docPath))
+                val_cmd = val_cmd.split(' ')
+                process = Popen(val_cmd , shell = False , stdout = PIPE, stderr = PIPE )
+                messages = []
+                for line in process.stdout:
+                    if line.find('found attribute "xml:base", but no attributes allowed here')==-1:
+                        messages.append(line)
+                for line in process.stderr:
+                    if line.find('Could not find or load main class com.thaiopensource.relaxng.util.Driver'):
+                        # handle errors like "jing not found"
+                        v_log.error('error during Jing validation: %s' % str(line))
+                        break
+                    if line.find('found attribute "xml:base", but no attributes allowed here')==-1:
+                        messages.append(line)
+                process.wait()
+                #returnCode = process.poll()
+                #self.rng_JingOk = not(returnCode)
+                self.rng_JingOk = len(messages)==0
+                self.rng_JingErrors = messages
+            except OSError, ose:
+                # handle errors like "java not found"...
+                v_log.error('error during Jing validation: %s' % str(ose))
         if self.runSCH:
             topLevelParams={}
             if self.publicURI:
@@ -98,3 +115,8 @@ class Validator(object):
             
         self.valNotOk = (self.runRNG and not(self.rngOk)) or (self.runSCH and not(self.schOk))
         self.valOk = not(self.valNotOk)
+        
+    def __del__(self):
+        # remove temporary path object removal
+        if self.file_is_temporary:
+            os.remove(self.docPath)
\ No newline at end of file
