@@ -24,6 +24,7 @@ from Utils import zipFiles , emailResults
 from Mobyle.MobyleError import MobyleError, UserValueError
 from Mobyle.Net import EmailAddress
 import Mobyle
+import Local.Policy
 
 log = logging.getLogger(__name__)
 
@@ -90,28 +91,47 @@ class WorkflowJob(object):
             self.email_notify =  email_notify  
             if self.email_notify != 'false' and not self.email:
                 raise MobyleError( "email adress must be specified when email_notify is set to %s" % email_notify )
-            
-            self.parameters = {}
-            for parameter in self.workflow.parameters:
-                # setting parameters which have a default value (important for hidden parameters which are not 
-                # accessed by JobFacade...
-                if not(parameter.isout) and parameter.vdef is not None:
-                    self.set_value(parameter.name, value=str(parameter.vdef))
             # job is just an "environment" folder for the job
             # it contains the instanciation of the job runner which seems to be hardcoded as "command runner"...
-            self._job = Job( self.workflow,
-                             self.cfg,
+            self._job = Job( service = self.workflow,
+                             cfg = self.cfg,
                              userEmail = self.email,
                              session = self.session,
                              workflowID = workflowID ,
                              )
             self.jobState = self._job.jobState
             self.id = self._job.getURL()
+            self.parameters = {}
+            for parameter in self.workflow.parameters:
+                # setting parameters which have a default value (important for hidden parameters which are not 
+                # accessed by JobFacade...
+                if not(parameter.isout) and len(parameter.vdef)!=0:
+                    self.set_value(parameter.name, value=parameter.getVdef())
             
     def getDir(self):        
         """ returns the absolute path of the workflow job directory """
         return self.jobState.getDir()
     
+    def getServiceName(self):
+        return self.workflow.getName()
+    
+    def getKey( self ):
+        """
+        @return: the unique key of this job
+        @rtype: string
+        """
+        return  self._job.getKey()
+    
+    def getEmail( self ):
+        """
+        @return: the email of the user or None if there is no email
+        @rtype: -L{Net.EmailAddress} instance
+        """
+        return self.email
+    
+    def getCommandLine(self):
+        return '' #polymorpism with Job used in LocalPolicy allow_to_be_executed
+    
     def set_status(self, status):
         log.debug("setting job %s status to %s" % (self.id, status))
         self.status_manager.setStatus( self.getDir() , status )
@@ -128,7 +148,7 @@ class WorkflowJob(object):
         self.parameters[parameter_name] = value
         self.parameters[parameter_name + '.src'] = src
         self.parameters[parameter_name + '.srcFileName'] = srcFileName
-        if value and value==wf_parameter.vdef:
+        if value and value==wf_parameter.getVdef():
             log.debug("setting %s parameter value to default value %s" %(parameter_name, wf_parameter.vdef))
             return            
         # save input value in a file
@@ -194,6 +214,20 @@ class WorkflowJob(object):
         """submit the job asynchronously"""
         self.validate()
         self.set_status(Status( code = 1 )) # status = submitted
+        
+        #raise a UserValueError if nb of job is over the limit accepted
+        if( self.email is not None ):
+            try:
+                Local.Policy.allow_to_be_executed( self )
+            except UserValueError, err:
+                self.set_status(Status(string="error",message="workflow execution failed"))
+                log.error( str(err))
+                raise err
+            except AttributeError:
+                #allow_to_be_executed is not in local policy
+                #so all jobs are allowed to run
+                pass
+                
         self._child_pid = os.fork()
         if self._child_pid==0:
             #Child code
@@ -440,10 +474,16 @@ class WorkflowJob(object):
                     log.debug('registry.getProgramUrl(t.service = %s,t.server= %s)' %(t.service , t.server) )
                     if t.server is None:
                         t.server = 'local'
-                    url = registry.getProgramUrl(t.service,t.server)
-                    j = Mobyle.JobFacade.JobFacade.getFromService(url, workflowId=self.id)
-                    job_signal = True
                     job_parameters = {}
+                    try:
+                        url = registry.getProgramUrl(t.service,t.server)
+                        j = Mobyle.JobFacade.JobFacade.getFromService(programUrl=url, workflowId=self.id)
+                        job_parameters['programName'] = url
+                    except:
+                        url = registry.getWorkflowUrl(t.service,t.server)
+                        j = Mobyle.JobFacade.JobFacade.getFromService(workflowUrl=url, workflowId=self.id)                        
+                        job_parameters['workflowUrl'] = url
+                    job_signal = True
                     for i_e in input_entries:
                         if i_e.has_key('value'):
                             job_parameters[i_e['parameter_id']]=i_e['value']
@@ -452,13 +492,16 @@ class WorkflowJob(object):
                             job_parameters[i_e['parameter_id']+'.srcFileName']=i_e['srcFileName']
                             job_parameters[i_e['parameter_id']+'.mode']='result'
                             job_parameters[i_e['parameter_id']+'.name']=i_e['parameter_id']+'.data'
-                    job_parameters['programName'] = url
                     job_parameters['email'] = self.email
                     try:
                         resp = j.create(request_dict=job_parameters)
+                        if not(resp.has_key('id')):
+                            raise WorkflowJobError(resp.get('errormsg',''))
                     except Exception, e:
-                        raise WorkflowJobError("error during submission of task %s(%s)" \
-                                                  %(t.id, t.description))
+                        log.error("error during submission of task %s(%s): %s" \
+                                                  %(t.id, t.description, e.message),exc_info=True)
+                        raise WorkflowJobError("error during submission of task %s(%s): %s" \
+                                                  %(t.id, t.description, e.message))
                     job_entry['job_id'] = resp['id']
                     if resp.has_key('errorparam') or resp.has_key('errormsg'):
                         raise WorkflowJobError("error during submission of task %s(%s).\n job %s message: %s: %s." \
